@@ -31,7 +31,7 @@ impl CaptureBase {
         let mut attr_type_str: String =
             serde_json::from_value(serde_json::to_value(&attribute.attr_type).unwrap()).unwrap();
         if let AttributeType::Sai = attribute.attr_type {
-            attr_type_str.push_str(&":".to_string());
+            attr_type_str.push(':');
             attr_type_str.push_str(attribute.sai.as_ref().unwrap_or(&"".to_string()));
         }
         self.attributes
